==> invoice-client-4.1.6-20200515.055925-40-sources.jar: com/xforceplus/seller/invoice/client/api/update/UpdatePreInvoiceApi.java <==
package com.xforceplus.seller.invoice.client.api.update;

import com.xforceplus.seller.invoice.client.model.update.UpdatePreInvoice;
import com.xforceplus.seller.invoice.client.model.update.UpdatePreInvoiceAndInvoiceExtFieldsRequest;
import com.xforceplus.xplatframework.model.Response;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@Api(value = "updatePreInvoice", description = "the sellerPreInvoice API")
public interface UpdatePreInvoiceApi {

    @ApiOperation(value = "根据票面抬头信息和业务单id更新预制发票票面抬头", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "X-Access-Token"),
            @Authorization(value = "X-Operation-Token")
    }, tags = {"updatePreInvoice",})
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "结果", response = Response.class)})
    @RequestMapping(value = "/updatePreInvoiceByTtitleNew",
            produces = {"application/json"},
            method = RequestMethod.POST)
    Response updatePreInvoice(@RequestBody UpdatePreInvoice updatePreInvoice );



    @ApiOperation(value = "业务单和明细补录时更新预制发票和发票", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "X-Access-Token"),
            @Authorization(value = "X-Operation-Token")
    }, tags = {"updatePreInvoiceAndInvoiceExtFields",})
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "结果", response = Response.class)})
    @RequestMapping(value = "/updatePreInvoiceAndInvoiceExtFields",
            produces = {"application/json"},
            method = RequestMethod.POST)
    Response updatePreInvoiceAndInvoiceExtFields(@RequestBody UpdatePreInvoiceAndInvoiceExtFieldsRequest request );
}

==> invoice-client-4.2.1-20250102.034116-2-sources.jar: com/xforceplus/seller/invoice/client/api/update/UpdatePreInvoiceApi.java <==
package com.xforceplus.seller.invoice.client.api.update;

import com.xforceplus.seller.invoice.client.model.InvoiceUpdateExtRequest;
import com.xforceplus.seller.invoice.client.model.update.UpdatePreInvoice;
import com.xforceplus.seller.invoice.client.model.update.UpdatePreInvoiceAndInvoiceExtFieldsRequest;
import com.xforceplus.xplatframework.model.Response;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@Api(value = "updatePreInvoice", description = "the sellerPreInvoice API")
public interface UpdatePreInvoiceApi {

    @ApiOperation(value = "根据票面抬头信息和业务单id更新预制发票票面抬头", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "X-Access-Token"),
            @Authorization(value = "X-Operation-Token")
    }, tags = {"updatePreInvoice",})
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "结果", response = Response.class)})
    @RequestMapping(value = "/updatePreInvoiceByTtitleNew",
            produces = {"application/json"},
            method = RequestMethod.POST)
    Response updatePreInvoice(@RequestBody UpdatePreInvoice updatePreInvoice );



    @ApiOperation(value = "业务单和明细补录时更新预制发票和发票", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "X-Access-Token"),
            @Authorization(value = "X-Operation-Token")
    }, tags = {"updatePreInvoiceAndInvoiceExtFields",})
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "结果", response = Response.class)})
    @RequestMapping(value = "/updatePreInvoiceAndInvoiceExtFields",
            produces = {"application/json"},
            method = RequestMethod.POST)
    Response updatePreInvoiceAndInvoiceExtFields(@RequestBody UpdatePreInvoiceAndInvoiceExtFieldsRequest request );

    @ApiOperation(value = "对外补录接口", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "X-Access-Token"),
            @Authorization(value = "X-Operation-Token")
    }, tags = {"openApiUpdateInvoiceExtFields",})
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "结果", response = Response.class)})
    @RequestMapping(value = "/openApiUpdateInvoiceExtFields",
            produces = {"application/json"},
            method = RequestMethod.POST)
    Response openApiUpdateInvoiceExtFields(@RequestBody InvoiceUpdateExtRequest invoiceUpdateExtRequest);
}
